import { Component, OnInit } from '@angular/core';
import { HttpErrorResponse } from '@angular/common/http';
import { ActivatedRoute, Router } from '@angular/router';

import { Course } from '../course.model';
import { CourseService } from '../course.service';

import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { _throw } from 'rxjs/observable/throw';

@Component({
  selector: 'app-course-browse',
  templateUrl: './course-browse.component.html',
  styleUrls: ['./course-browse.component.css']
})
export class CourseBrowseComponent implements OnInit {

  courses: Observable<Course[]>;
  displayCourses: Course[] = [];

  constructor(private courseService: CourseService, private router: Router, private activatedRoute: ActivatedRoute) { }

  ngOnInit() {
    this.courses = this.courseService.getCourses().pipe(
      catchError(err => {
        if (err.error instanceof Error) {
           alert(`An error occurred: ${err.error.message}`);
         }
         else {
           alert(`Backend return code: ${err.status} \nError: ${err.message}`);
         }
        return _throw(err);
      })
    );
  }

  navToEdit(code: string) {
    this.router.navigate(['../edit', {code}], {relativeTo: this.activatedRoute})
  }

}
